==> react-truncate-jsx-1.0.2.tgz: package/lib/esm/stories/Truncate.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useState } from 'react';
import Truncate from '../Truncate';
import TruncateList from '../TruncateList';
var data = ['New York', 'Double bed', 'Free Cables', 'XXX', 'Pool', 'Luxury'];
var data2 = [
    'San Jose',
    'Single bed',
    'Luxury',
    'XXX',
    'Secret-Door',
    'Fire-Place',
];
var Tag = forwardRef(function (_a, ref) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return (_jsx("div", __assign({ ref: ref, style: {
            padding: '3px 5px',
            background: '#bababa',
            flexShrink: 0,
            marginRight: 5,
        } }, props, { children: children }), void 0));
});
var Ellipsis = forwardRef(function (_a, ref) {
    var moreCount = _a.moreCount, moreChildren = _a.moreChildren, props = __rest(_a, ["moreCount", "moreChildren"]);
    return (_jsxs("div", __assign({ ref: ref }, props, { style: { flexShrink: 0 } }, { children: ["+", moreCount, " tags"] }), void 0));
});
export var Main = function () {
    var _a = useState(false), isTruncating = _a[0], setTruncate = _a[1];
    var _b = useState(data), tags = _b[0], setTags = _b[1];
    return (_jsxs("div", { children: [_jsx("h3", { children: "JSX Ellipsis playground" }, void 0),
            _jsxs("div", __assign({ style: { padding: '10px 0' } }, { children: [_jsx("button", __assign({ onClick: function () { return setTags(function (t) { return t.slice(1); }); } }, { children: "reduce tags" }), void 0),
                    _jsx("button", __assign({ onClick: function () { return setTags(data2); } }, { children: "Switch data" }), void 0),
                    _jsx("button", __assign({ onClick: function () { return setTruncate(function (t) { return !t; }); } }, { children: "toggle" }), void 0)] }), void 0),
            _jsx("div", __assign({ style: { width: 350, background: 'blue', padding: 10 } }, { children: _jsx(Truncate, __assign({ isTruncating: isTruncating }, { children: _jsx("div", __assign({ style: {
                            display: 'flex',
                            flexWrap: 'wrap',
                            alignItems: 'center',
                            background: 'lightcyan',
                        } }, { children: _jsx(TruncateList, __assign({ ellipsis: Ellipsis }, { children: tags.map(function (t) { return (_jsx(Tag, { children: t }, t)); }) }), void 0) }), void 0) }), void 0) }), void 0)] }, void 0));
};
export default {
    title: 'Components/Main',
    component: Main,
};

==> react-truncate-jsx-1.0.4.tgz: package/lib/esm/stories/Truncate.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useState } from 'react';
import Truncate, { TruncateList } from '../';
var data = ['New York', 'Double bed', 'Free Cables', 'XXX', 'Pool', 'Luxury'];
var data2 = [
    'San Jose',
    'Single bed',
    'Luxury',
    'XXX',
    'Secret-Door',
    'Fire-Place',
];
var Tag = forwardRef(function (_a, ref) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return (_jsx("div", __assign({ ref: ref, style: {
            padding: '3px 5px',
            background: '#bababa',
            flexShrink: 0,
            marginRight: 5,
        } }, props, { children: children }), void 0));
});
var Ellipsis = forwardRef(function (_a, ref) {
    var moreCount = _a.moreCount, moreChildren = _a.moreChildren, props = __rest(_a, ["moreCount", "moreChildren"]);
    return (_jsxs("div", __assign({ ref: ref }, props, { style: { flexShrink: 0 } }, { children: ["+", moreCount, " tags"] }), void 0));
});
export var Main = function () {
    var _a = useState(false), isTruncating = _a[0], setTruncate = _a[1];
    var _b = useState(data), tags = _b[0], setTags = _b[1];
    return (_jsxs("div", { children: [_jsx("h3", { children: "JSX Ellipsis playground" }, void 0),
            _jsxs("div", __assign({ style: { padding: '10px 0' } }, { children: [_jsx("button", __assign({ onClick: function () { return setTags(function (t) { return t.slice(1); }); } }, { children: "reduce tags" }), void 0),
                    _jsx("button", __assign({ onClick: function () { return setTags(data2); } }, { children: "Switch data" }), void 0),
                    _jsx("button", __assign({ onClick: function () { return setTruncate(function (t) { return !t; }); } }, { children: "toggle" }), void 0)] }), void 0),
            _jsx("div", __assign({ style: { width: 350, background: 'blue', padding: 10 } }, { children: _jsx(Truncate, __assign({ isTruncating: isTruncating }, { children: _jsx("div", __assign({ style: {
                            display: 'flex',
                            flexWrap: 'wrap',
                            alignItems: 'center',
                            background: 'lightcyan',
                        } }, { children: _jsx(TruncateList, __assign({ ellipsis: Ellipsis }, { children: tags.map(function (t) { return (_jsx(Tag, { children: t }, t)); }) }), void 0) }), void 0) }), void 0) }), void 0)] }, void 0));
};
export default {
    title: 'Components/Main',
    component: Main,
};
